@@ -1,4 +1,5 @@
 #!/usr/bin/env python
 
-from sixel import *
+from sixel import main
+
 main()
